@@ -13,6 +13,15 @@ class DynamicHTMLFile(template.TemplateFile):
         return template.TemplateFile.render(
             self, content=content, attributes=attributes, **kwargs)
 
+    def render_macro(self, macro, global_scope=False, parameters=None):
+        if parameters is None: parameters = {}
+        
+        parameters.setdefault('content', {})
+        parameters.setdefault('attributes', {})
+
+        return template.TemplateFile.render_macro(
+            self, macro, global_scope=global_scope, parameters=parameters)
+
     def mtime(self):
         """Return the most recent modification times from the template
         file itself and any XSS-files included."""
